pub type HandlerResponse<T> = Result<T, ServiceError>;Expand description
The response type returned by implementors of a humblegen service trait function.
Aliased Type
pub enum HandlerResponse<T> {
Ok(T),
Err(ServiceError),
}pub type HandlerResponse<T> = Result<T, ServiceError>;The response type returned by implementors of a humblegen service trait function.
pub enum HandlerResponse<T> {
Ok(T),
Err(ServiceError),
}